@@ -1,33 +1,32 @@
-import asyncio
 import json
-from copy import deepcopy
+import asyncio
 from time import time
-from typing import Dict, List, Literal, Union
-
-from httpx import AsyncClient, HTTPError
+from copy import deepcopy
+from typing import Dict, List, Union, Literal
+from datetime import datetime, timezone, timedelta
 
 from nonebot import require
 from nonebot.log import logger
+from httpx import HTTPError, AsyncClient
 
-require("nonebot_plugin_htmlrender")
-from nonebot_plugin_htmlrender import template_to_pic
-
-from .__utils__ import LOCAL_DIR, SCALE_FACTOR, TPL_VERSION, download
+from .__utils__ import LOCAL_DIR, TPL_VERSION, SCALE_FACTOR, download
 from .data_convert import (
+    transFromEnka,
+    transToTeyvat,
     simplDamageRes,
     simplFightProp,
     simplTeamDamageRes,
-    transFromEnka,
-    transToTeyvat,
 )
 
+require("nonebot_plugin_htmlrender")
+from nonebot_plugin_htmlrender import template_to_pic  # noqa: E402
 
-async def queryPanelApi(uid: str, source: Literal["enka", "mgg"] = "enka") -> Dict:
+
+async def queryPanelApi(uid: str) -> Dict:
     """
     原神游戏内角色展柜数据请求
 
     * ``param uid: str`` 查询用户 UID
-    * ``param source: Literal["enka", "mgg"] = "enka"`` 查询接口
     - ``return: Dict`` 查询结果，出错时返回 ``{"error": "错误信息"}``
     """
     enkaMirrors = [
@@ -40,7 +39,7 @@ async def queryPanelApi(uid: str, source: Literal["enka", "mgg"] = "enka") -> Di
         for idx, root in enumerate(enkaMirrors):
             try:
                 res = await client.get(
-                    url=f"{root}/u/{uid}/__data.json",
+                    url=f"{root}/api/uid/{uid}",
                     headers={
                         "Accept": "application/json",
                         "Accept-Language": "zh-CN,zh;q=0.9,en;q=0.8,en-US;q=0.7",
@@ -53,6 +52,7 @@ async def queryPanelApi(uid: str, source: Literal["enka", "mgg"] = "enka") -> Di
                             "Chrome/102.0.0.0 Mobile Safari/537.36"
                         ),
                     },
+                    follow_redirects=True,
                     timeout=20.0,
                 )
                 resJson = res.json()
@@ -72,14 +72,16 @@ async def queryPanelApi(uid: str, source: Literal["enka", "mgg"] = "enka") -> Di
     return resJson
 
 
-async def queryDamageApi(body: Dict, mode: Literal["single", "team"] = "single") -> Dict:
+async def queryDamageApi(
+    body: Dict, mode: Literal["single", "team"] = "single"
+) -> Dict:
     """
     角色伤害计算数据请求（提瓦特小助手）
 
     * ``param body: Dict`` 查询角色数据
     * ``param mode: Literal["single", "team"] = "single"`` 查询接口类型，默认请求角色伤害接口，传入 ``"team"`` 请求队伍伤害接口
     - ``return: Dict`` 查询结果，出错时返回 ``{}``
-    """
+    """  # noqa: E501
     apiMap = {
         "single": "https://api.lelaer.com/ys/getDamageResult.php",
         "team": "https://api.lelaer.com/ys/getTeamResult.php",
@@ -90,23 +92,22 @@ async def queryDamageApi(body: Dict, mode: Literal["single", "team"] = "single")
                 apiMap[mode],
                 json=body,
                 headers={
-                    "referer": "https://servicewechat.com/wx2ac9dce11213c3a8/192/page-frame.html",
+                    "referer": "https://servicewechat.com/wx2ac9dce11213c3a8/192/page-frame.html",  # noqa: E501
                     "user-agent": (
-                        "Mozilla/5.0 (Linux; Android 12; SM-G977N Build/SP1A.210812.016; wv) "
-                        "AppleWebKit/537.36 (KHTML, like Gecko) Version/4.0 Chrome/86.0.4240.99 "
-                        "XWEB/4375 MMWEBSDK/20221011 Mobile Safari/537.36 MMWEBID/4357 "
-                        "MicroMessenger/8.0.30.2244(0x28001E44) WeChat/arm64 Weixin GPVersion/1 "
-                        "NetType/WIFI Language/zh_CN ABI/arm64 MiniProgramEnv/android"
+                        "Mozilla/5.0 (Linux; Android 12; SM-G977N Build/SP1A.210812.016"
+                        "; wv) AppleWebKit/537.36 (KHTML, like Gecko) Version/4.0 "
+                        "Chrome/86.0.4240.99 XWEB/4375 MMWEBSDK/20221011 Mobile Safari"
+                        "/537.36 MMWEBID/4357 MicroMessenger/8.0.30.2244(0x28001E44) "
+                        "WeChat/arm64 Weixin GPVersion/1 NetType/WIFI Language/zh_CN "
+                        "ABI/arm64 MiniProgramEnv/android"
                     ),
                 },
+                timeout=20.0,
             )
             return res.json()
         except (HTTPError, json.decoder.JSONDecodeError) as e:
             logger.opt(exception=e).error("提瓦特小助手接口无法访问或返回错误")
             return {}
-        except Exception as e:
-            logger.opt(exception=e).error("提瓦特小助手接口错误")
-            return {}
 
 
 async def getAvatarData(uid: str, char: str = "全部") -> Dict:
@@ -121,20 +122,27 @@ async def getAvatarData(uid: str, char: str = "全部") -> Dict:
     cache = LOCAL_DIR / "cache" / f"{uid}.json"
     if cache.exists():
         cacheData = json.loads(cache.read_text(encoding="utf-8"))
-        nextQueryTime = cacheData["next"]
+        nextQueryTime: int = cacheData["next"]
     else:
         cacheData, nextQueryTime = {}, 0
 
+    refreshed, _tip, _time = [], "", 0
+
     if int(time()) <= nextQueryTime:
-        logger.info("UID{} 的角色展柜数据刷新冷却还有 {} 秒！".format(uid, nextQueryTime - int(time())))
+        _tip, _time = "warning", nextQueryTime
+        logger.info(f"UID{uid} 的角色展柜数据刷新冷却还有 {int(nextQueryTime - time())} 秒！")
     else:
         logger.info(f"UID{uid} 的角色展柜数据正在刷新！")
         newData = await queryPanelApi(uid)
+        _time = time()
+        # 没有缓存 & 本次刷新失败，返回错误信息
         if not cacheData and newData.get("error"):
             return newData
+        # 本次刷新成功，处理全部角色
         elif not newData.get("error"):
+            _tip = "success"
             avatarsCache = {str(x["id"]): x for x in cacheData.get("avatars", [])}
-            now, wait4Dmg, avatars, avatarIdsNew = int(time()), {}, [], []
+            now, wait4Dmg, avatars = int(time()), {}, []
             for newAvatar in newData["avatarInfoList"]:
                 if newAvatar["avatarId"] in [10000005, 10000007]:
                     logger.info("旅行者面板查询暂未支持！")
@@ -152,22 +160,19 @@ async def getAvatarData(uid: str, char: str = "全部") -> Dict:
                         logger.info(f"UID{uid} 的 {tmp['name']} 伤害计算结果无需刷新！")
                         tmp["damage"], gotDmg = cacheDmg, True
                     else:
-                        logger.info(
-                            "UID{} 的 {} 数据发生变化：\n{}\n{}".format(
+                        logger.debug(
+                            "UID{} 的 {} 数据变化细则：\n{}\n{}".format(
                                 uid, tmp["name"], avatarsCache[str(tmp["id"])], nowStat
                             )
                         )
-                avatarIdsNew.append(tmp["id"])
+                refreshed.append(tmp["id"])
                 avatars.append(tmp)
                 if not gotDmg:
                     wait4Dmg[str(len(avatars) - 1)] = tmp
 
             if wait4Dmg:
-                logger.info(
-                    "正在为 UID{} 的 {} 重新请求伤害计算接口".format(
-                        uid, "/".join(f"[{aI}]{a['name']}" for aI, a in wait4Dmg.items())
-                    )
-                )
+                _names = "/".join(f"[{aI}]{a['name']}" for aI, a in wait4Dmg.items())
+                logger.info(f"正在为 UID{uid} 的 {_names} 重新请求伤害计算接口")
                 # 深拷贝避免转换对上下文中的 avatars 产生影响
                 wtf = deepcopy([a for _, a in wait4Dmg.items()])
                 teyvatBody = await transToTeyvat(wtf, uid)
@@ -176,10 +181,8 @@ async def getAvatarData(uid: str, char: str = "全部") -> Dict:
                     teyvatRaw.get("result", [])
                 ):
                     logger.error(
-                        (
-                            f"UID{uid} 的 {len(wait4Dmg)} 位角色伤害计算请求失败！"
-                            f"\n>>>> [提瓦特返回] {teyvatRaw}"
-                        )
+                        f"UID{uid} 的 {len(wait4Dmg)} 位角色伤害计算请求失败！"
+                        f"\n>>>> [提瓦特返回] {teyvatRaw}"
                     )
                 else:
                     for dmgIdx, dmgData in enumerate(teyvatRaw.get("result", [])):
@@ -191,16 +194,26 @@ async def getAvatarData(uid: str, char: str = "全部") -> Dict:
                 *[
                     aData
                     for _, aData in avatarsCache.items()
-                    if aData["id"] not in avatarIdsNew
+                    if aData["id"] not in refreshed
                 ],
             ]
             cacheData["next"] = now + newData["ttl"]
             cache.write_text(
                 json.dumps(cacheData, ensure_ascii=False, indent=2), encoding="utf-8"
             )
+        # 有缓存 & 本次刷新失败，打印错误信息
+        else:
+            _tip = "error"
+            logger.error(newData["error"])
 
     # 获取所需角色数据
     if char == "全部":
+        # 为本次更新的角色添加刷新标记
+        for aIdx, aData in enumerate(cacheData["avatars"]):
+            cacheData["avatars"][aIdx]["refreshed"] = aData["id"] in refreshed
+        # 格式化刷新时间
+        _datetime = datetime.fromtimestamp(_time, timezone(timedelta(hours=8)))
+        cacheData["timetips"] = [_tip, _datetime.strftime("%Y-%m-%d %H:%M:%S")]
         return cacheData
     searchRes = [x for x in cacheData["avatars"] if x["name"] == char]
     return (
@@ -222,35 +235,47 @@ async def getPanel(uid: str, char: str = "全部") -> Union[bytes, str]:
     * ``param char: str = "全部"`` 查询角色
     - ``return: Union[bytes, str]`` 查询结果。一般返回图片字节，出错时返回错误信息字符串
     """
+    htmlBase = str(LOCAL_DIR.resolve())
+
     # 获取面板数据
     data = await getAvatarData(uid, char)
     if data.get("error"):
         return data["error"]
-    if char == "全部":
-        return "成功获取了 UID{} 的{}等 {} 位角色数据！".format(
-            uid, "、".join(a["name"] for a in data["avatars"]), len(data["avatars"])
-        )
+
+    mode = "list" if char == "全部" else "panel"
 
     # 图标下载任务
-    dlTasks = [
-        download(data["icon"], local=char),
-        download(data["gachaAvatarImg"], local=char),
-        *[download(sData["icon"], local=char) for _, sData in data["skills"].items()],
-        *[download(conData["icon"], local=char) for conData in data["consts"]],
-        download(data["weapon"]["icon"], local="weapon"),
-        *[download(relicData["icon"], local="artifacts") for relicData in data["relics"]],
-    ]
+    dlTasks = (
+        [
+            download(data["icon"], local=char),
+            download(data["gachaAvatarImg"], local=char),
+            *[
+                download(sData["icon"], local=char)
+                for _, sData in data["skills"].items()
+            ],
+            *[download(conData["icon"], local=char) for conData in data["consts"]],
+            download(data["weapon"]["icon"], local="weapon"),
+            *[
+                download(relicData["icon"], local="artifacts")
+                for relicData in data["relics"]
+            ],
+        ]
+        if mode == "panel"
+        else [download(role["icon"], local=role["name"]) for role in data["avatars"]]
+    )
     await asyncio.gather(*dlTasks)
     dlTasks.clear()
 
+    # 如果渲染角色面板，额外根据需要精简面板数据（缓存中仍保留全部数据）
+    if mode == "panel":
+        data["fightProp"] = await simplFightProp(
+            data["fightProp"], data["baseProp"], char, data["element"]
+        )
+
     # 渲染截图
-    data["fightProp"] = await simplFightProp(
-        data["fightProp"], data["baseProp"], char, data["element"]
-    )
-    htmlBase = str(LOCAL_DIR.resolve())
     return await template_to_pic(
         template_path=htmlBase,
-        template_name=f"panel-{TPL_VERSION}.html",
+        template_name=f"{mode}-{TPL_VERSION}.html",
         templates={"css": TPL_VERSION, "uid": uid, "data": data},
         pages={
             "device_scale_factor": SCALE_FACTOR,
@@ -315,7 +340,7 @@ async def getTeam(uid: str, chars: List[str] = []) -> Union[bytes, str]:
     teyvatRaw = await queryDamageApi(teyvatBody, "team")
     if teyvatRaw.get("code", "x") != 200 or not teyvatRaw.get("result"):
         logger.error(
-            (f"UID{uid} 的 {len(extract)} 位角色队伍伤害计算请求失败！" f"\n>>>> [提瓦特返回] {teyvatRaw}")
+            f"UID{uid} 的 {len(extract)} 位角色队伍伤害计算请求失败！" f"\n>>>> [提瓦特返回] {teyvatRaw}"
         )
         return f"玩家 {uid} 队伍伤害计算失败，接口可能发生变动！" if teyvatRaw else "啊哦，队伍伤害计算小程序状态异常！"
     try:
